/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.bookkeeper.tls;

import io.netty.buffer.ByteBufAllocator;
import io.netty.handler.ssl.SslHandler;

import org.apache.bookkeeper.conf.AbstractConfiguration;

/**
 * A factory to manage the security handlers.
 */
public interface SecurityHandlerFactory {

    /**
     * The security handler type.
     */
    enum NodeType {
        Unknown,
        Client,
        Server,
    }

    String getHandlerName();

    void init(NodeType type, AbstractConfiguration conf, ByteBufAllocator allocator) throws SecurityException;

    SslHandler newTLSHandler();

    default SslHandler newTLSHandler(String host, int port) {
        return this.newTLSHandler();
    }
}
